@@ -69,6 +69,11 @@ class Definition:
 		##########
 		if self.default_value is None:
 			self.nullable = True
+		# Default Value
+		###############
+		if isinstance(self.default_value, Utils.DataDefinitionDefaultValue):
+			if self.nullable is True:
+				self.default_value = None
 		# Data Format
 		#############
 		if self.data_type is DataType.OneOf:
